@@ -7,6 +7,7 @@ from aws_cdk import aws_ec2 as ec2
 from aws_cdk import aws_efs as efs
 from aws_cdk import aws_elasticloadbalancingv2 as elb
 from aws_cdk import aws_iam as iam
+from aws_cdk.aws_elasticloadbalancingv2_targets import InstanceTarget
 import requests
 
 
@@ -94,7 +95,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 		self.vpc = ec2.Vpc(
 			self,
 			_id,
-			max_azs=1,
+			max_azs=2 if self.use_https else 1,
 			nat_gateways=0,
 			subnet_configuration=[
 				ec2.SubnetConfiguration(name='public', subnet_type=ec2.SubnetType.PUBLIC)
@@ -162,6 +163,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 			self.add_leader_commands(
 				udata,
 				f'aws s3 sync s3://{self.config["aws"]["bucket"]} /mnt/efs',
+				'mkdir -p /mnt/efs/data',
 				'cd /mnt/efs/data',
 				*[f'curl -O {data_url}' for data_url in self.data_urls],
 				'cd -'
@@ -244,8 +246,12 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 			'substrate-elb',
 			vpc=self.vpc
 		)
-		listener = load_balancer.add_listener('substrate-elb-listener', port=443)
-		listener.add_targets('substrate-ec2-targets', *self.nodes)
+		listener = load_balancer.add_listener('substrate-elb-listener', port=80)
+		listener.add_targets(
+			'substrate-ec2-targets',
+			port=80,
+			targets=[InstanceTarget(instance) for instance in self.nodes]
+		)
 
 	def provision_fs(self):
 		efs_sg = ec2.SecurityGroup(self, 'substrate-efs-sg', vpc=self.vpc)
